% MAKE_PATH1_CLIMATE_BASE

% Input files are   (1) distdata.dat: Distance Along Path (m)
%                   (2) sfctemp.dat:  Surface Temperature (K)
%                   (3) pwat.dat:     Water Content (kg/m2)
%                   (4) lhflx.dat:    Latent Heat Flux (W/m2)
%                   (5) prate.dat:    Precipitation (kg/m2/s)
%                   (6) rhum.dat:     Relative Humidity (%)
%                   (7) runoff.dat:   Surface Runoff (kg/m2/s)

% Output fields are (1) Distance Along Path (m)
%                   (2) Surface Temperature (k)
%                   (3) Cloud Temperature (k)
%                   (4) Water Content (m)
%                   (5) Evaporation, (m/s)
%                   (6) Precipitation, (m/s)
%                   (7) Relative Humidity
%                   (8) Surface Runoff (m/s)

load distdata.dat;
load sfctemp.dat;
load pwat.dat;
load lhflx.dat;
load prate.dat;
load rhum.dat;
load runoff.dat;

% Data are presented in reverse order (trajectory end first).  Reverse 'em:

climate_r(:,1)  = distdata(:,1); 
climate_r(:,2)  = sfctemp(:,1); 
climate_r(:,3)  = pwat(:,1); 
climate_r(:,4)  = lhflx(:,1); 
climate_r(:,5)  = prate(:,1); 
climate_r(:,6)  = rhum(:,1); 
climate_r(:,7)  = runoff(:,1); 

number_nodes  = size(climate_r,1);

for i=1:1:number_nodes
  climate((number_nodes+1)-i,1) = climate_r(i,1);
  climate((number_nodes+1)-i,2) = climate_r(i,2);
  climate((number_nodes+1)-i,3) = climate_r(i,3);
  climate((number_nodes+1)-i,4) = climate_r(i,4);
  climate((number_nodes+1)-i,5) = climate_r(i,5);
  climate((number_nodes+1)-i,6) = climate_r(i,6);
  climate((number_nodes+1)-i,7) = climate_r(i,7);
end

% First, we'll shrink the pathlength a bit to be an integer number 
% of nodes (its current length is just shy of 4850 km).  We'll also 
% ensure that the ocean/land boundary coincides with a node.  Set 
% grid spacing:

l_incr  = 10.0*1000.0; % 10 km resolution;

i_start_l = 1;
start_l   = climate(i_start_l,1);
i_stop_l  = number_nodes;
stop_l    = climate(i_stop_l,1);

% First shrink entire domain a little bit:

shrinkfactor = ((floor(stop_l/l_incr))*l_incr)/stop_l;

for i=1:1:number_nodes
  climate(i,1)=shrinkfactor*climate(i,1);
end

% New pathlength:

stop_l    = climate(i_stop_l,1);

% See if given location is ocean or land:

for i=1:1:number_nodes
ocean(i,1)=climate(i,1);
  if climate(i,7) == 0.0
    ocean(i,2)   = 1;
    i_land       = i+1;
    land         = climate(i+1,1);
  else
    ocean(i,2) = 0;
  end
end

length1   = (floor(land/l_incr))*l_incr;
length2   = stop_l-length1;

for i=1:1:number_nodes
  if i<=i_land
    frac = climate(i,1)/land;
    climate(i,1) = frac*length1;
  else
    frac = (climate(i,1)-land)/(stop_l-land);
    climate(i,1) = (floor(land/l_incr)*l_incr)+frac*length2;
  end
end

% Redefine land:

land = climate(i_land,1);

% Next, we'll project the data onto a regularly-spaced grid:

number_total = (stop_l-start_l+1)/l_incr;

for i=1:1:number_total
  l(i) = start_l+(i-1)*l_incr;
end

col1 = climate(:,1);
col2 = climate(:,2);
col3 = climate(:,3);
col4 = climate(:,4);
col5 = climate(:,5);
col6 = climate(:,6);
col7 = climate(:,7);

climate_regular(:,1) = l';
climate_regular(:,2) = (interp1(col1,col2,l,'linear'))';
climate_regular(:,3) = (interp1(col1,col3,l,'linear'))';
climate_regular(:,4) = (interp1(col1,col4,l,'linear'))';
climate_regular(:,5) = (interp1(col1,col5,l,'linear'))';
climate_regular(:,6) = (interp1(col1,col6,l,'linear'))';
climate_regular(:,7) = (interp1(col1,col7,l,'linear'))';

number_nodes  = size(climate_regular,1);

% Again see if given location is ocean or land, and make sure 
% that there's no runoff where surface is ocean:

clear ocean;

for i=1:1:number_nodes
  ocean(i,1) = climate_regular(i,1);
  if climate_regular(i,1) < land
    ocean(i,2)           = 1;
    climate_regular(i,7) = 0.0;
    i_land               = i+1;
  else
    ocean(i,2)           = 0;
  end
end

% Now we can start working with the data.  First, convert to useful units:

% Surface temp: already in K; no change.
ts_raw(:,1)     = climate_regular(:,1);
ts_raw(:,2)     = climate_regular(:,2);

% Water content: in kg/m2; want m water-equivalent:
wc_raw(:,1)     = climate_regular(:,1);
wc_raw(:,2)     = climate_regular(:,3)/1000.0;

% Evaporation: expressed in terms of latent heat (W/m2); 
% want m/s:
E_raw(:,1)      = climate_regular(:,1);
E_raw(:,2)      = climate_regular(:,4)/(2.272e+06*1000.0);

% Precipitation: in kg/m2/s; want m/s:
P_raw(:,1)      = climate_regular(:,1);
P_raw(:,2)      = climate_regular(:,5)/1000.0;

% Relative humidity: in percent (%); want decimal value:
h_raw(:,1)      = climate_regular(:,1);
h_raw(:,2)      = climate_regular(:,6)/100.0;

% Runoff: in kg/m2; want m:
run_raw(:,1)    = climate_regular(:,1);
run_raw(:,2)    = climate_regular(:,7)/1000;

% Now smooth the data.  First smooth ts_raw.  The function 'filter', is, 
% sadly, assymetric.  We'll thus apply it twice (once in each direction) 
% for each filtered variable and average the results.  Backwards first:

x_f(1)=ts_raw(1,2)-11*(ts_raw(2,2)-ts_raw(1,2));
x_f(2)=ts_raw(1,2)-10*(ts_raw(2,2)-ts_raw(1,2));
x_f(3)=ts_raw(1,2)-9*(ts_raw(2,2)-ts_raw(1,2));
x_f(4)=ts_raw(1,2)-8*(ts_raw(2,2)-ts_raw(1,2));
x_f(5)=ts_raw(1,2)-7*(ts_raw(2,2)-ts_raw(1,2));
x_f(6)=ts_raw(1,2)-6*(ts_raw(2,2)-ts_raw(1,2));
x_f(7)=ts_raw(1,2)-5*(ts_raw(2,2)-ts_raw(1,2));
x_f(8)=ts_raw(1,2)-4*(ts_raw(2,2)-ts_raw(1,2));
x_f(9)=ts_raw(1,2)-3*(ts_raw(2,2)-ts_raw(1,2));
x_f(10)=ts_raw(1,2)-2*(ts_raw(2,2)-ts_raw(1,2));
x_f(11)=ts_raw(1,2)-1*(ts_raw(2,2)-ts_raw(1,2));

for i=1:1:number_nodes
  x_f(i+11)=ts_raw(i,2);
end

a_f=1;
b_f=[1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12];

ts_filt_1=filter(b_f,a_f,x_f);

for i=1:1:number_nodes
  ts_1(i,1)=l(i);
  ts_1(i,2)=ts_filt_1(i+11);
  % The two following lines create a reversed record so we 
  % can filter in the forward direction:
  ts_raw_rev(i,1)=ts_raw((number_nodes-i)+1,1);
  ts_raw_rev(i,2)=ts_raw((number_nodes-i)+1,2);
end

% Now forwards:

x_f(1)=ts_raw_rev(1,2)-11*(ts_raw_rev(2,2)-ts_raw_rev(1,2));
x_f(2)=ts_raw_rev(1,2)-10*(ts_raw_rev(2,2)-ts_raw_rev(1,2));
x_f(3)=ts_raw_rev(1,2)-9*(ts_raw_rev(2,2)-ts_raw_rev(1,2));
x_f(4)=ts_raw_rev(1,2)-8*(ts_raw_rev(2,2)-ts_raw_rev(1,2));
x_f(5)=ts_raw_rev(1,2)-7*(ts_raw_rev(2,2)-ts_raw_rev(1,2));
x_f(6)=ts_raw_rev(1,2)-6*(ts_raw_rev(2,2)-ts_raw_rev(1,2));
x_f(7)=ts_raw_rev(1,2)-5*(ts_raw_rev(2,2)-ts_raw_rev(1,2));
x_f(8)=ts_raw_rev(1,2)-4*(ts_raw_rev(2,2)-ts_raw_rev(1,2));
x_f(9)=ts_raw_rev(1,2)-3*(ts_raw_rev(2,2)-ts_raw_rev(1,2));
x_f(10)=ts_raw_rev(1,2)-2*(ts_raw_rev(2,2)-ts_raw_rev(1,2));
x_f(11)=ts_raw_rev(1,2)-1*(ts_raw_rev(2,2)-ts_raw_rev(1,2));

for i=1:1:number_nodes
  x_f(i+11)=ts_raw_rev(i,2);
end

a_f=1;
b_f=[1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12];

ts_filt_2=filter(b_f,a_f,x_f);

for i=1:1:number_nodes
  ts_2_rev(i,1)=l((number_nodes-i)+1);
  ts_2_rev(i,2)=ts_filt_2(i+11);
end

for i=1:1:number_nodes
  ts_2(i,1)=l(i);
  ts_2(i,2)=ts_2_rev((number_nodes-i)+1,2);
  ts(i,1)=l(i);
  ts(i,2)=(ts_1(i,2)+ts_2(i,2))/2;
end

% Done smoothing ts.  Next, calculate cloud temperature tc field.  
% Since it is derived from the smoothed surface temperature field, 
% no smoothing is needed:

for i=1:1:number_nodes
  tc(i,1)       = ts(i,1);
  tc(i,2)       = ts(i,2)-6.0;
  %tc(i,2)       = temp_cloud(ts(i,2));
end

% Smooth wc_raw.  Backwards first:

x_f(1)=wc_raw(1,2)-11*(wc_raw(2,2)-wc_raw(1,2));
x_f(2)=wc_raw(1,2)-10*(wc_raw(2,2)-wc_raw(1,2));
x_f(3)=wc_raw(1,2)-9*(wc_raw(2,2)-wc_raw(1,2));
x_f(4)=wc_raw(1,2)-8*(wc_raw(2,2)-wc_raw(1,2));
x_f(5)=wc_raw(1,2)-7*(wc_raw(2,2)-wc_raw(1,2));
x_f(6)=wc_raw(1,2)-6*(wc_raw(2,2)-wc_raw(1,2));
x_f(7)=wc_raw(1,2)-5*(wc_raw(2,2)-wc_raw(1,2));
x_f(8)=wc_raw(1,2)-4*(wc_raw(2,2)-wc_raw(1,2));
x_f(9)=wc_raw(1,2)-3*(wc_raw(2,2)-wc_raw(1,2));
x_f(10)=wc_raw(1,2)-2*(wc_raw(2,2)-wc_raw(1,2));
x_f(11)=wc_raw(1,2)-1*(wc_raw(2,2)-wc_raw(1,2));

for i=1:1:number_nodes
  x_f(i+11)=wc_raw(i,2);
end

a_f=1;
b_f=[1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12];

wc_filt_1=filter(b_f,a_f,x_f);

for i=1:1:number_nodes
  wc_1(i,1)=l(i);
  wc_1(i,2)=wc_filt_1(i+11);
  % The two following lines create a reversed record so we 
  % can filter in the forward direction:
  wc_raw_rev(i,1)=wc_raw((number_nodes-i)+1,1);
  wc_raw_rev(i,2)=wc_raw((number_nodes-i)+1,2);
end

% Now forwards:

x_f(1)=wc_raw_rev(1,2)-11*(wc_raw_rev(2,2)-wc_raw_rev(1,2));
x_f(2)=wc_raw_rev(1,2)-10*(wc_raw_rev(2,2)-wc_raw_rev(1,2));
x_f(3)=wc_raw_rev(1,2)-9*(wc_raw_rev(2,2)-wc_raw_rev(1,2));
x_f(4)=wc_raw_rev(1,2)-8*(wc_raw_rev(2,2)-wc_raw_rev(1,2));
x_f(5)=wc_raw_rev(1,2)-7*(wc_raw_rev(2,2)-wc_raw_rev(1,2));
x_f(6)=wc_raw_rev(1,2)-6*(wc_raw_rev(2,2)-wc_raw_rev(1,2));
x_f(7)=wc_raw_rev(1,2)-5*(wc_raw_rev(2,2)-wc_raw_rev(1,2));
x_f(8)=wc_raw_rev(1,2)-4*(wc_raw_rev(2,2)-wc_raw_rev(1,2));
x_f(9)=wc_raw_rev(1,2)-3*(wc_raw_rev(2,2)-wc_raw_rev(1,2));
x_f(10)=wc_raw_rev(1,2)-2*(wc_raw_rev(2,2)-wc_raw_rev(1,2));
x_f(11)=wc_raw_rev(1,2)-1*(wc_raw_rev(2,2)-wc_raw_rev(1,2));

for i=1:1:number_nodes
  x_f(i+11)=wc_raw_rev(i,2);
end

a_f=1;
b_f=[1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12];

wc_filt_2=filter(b_f,a_f,x_f);

for i=1:1:number_nodes
  wc_2_rev(i,1)=l((number_nodes-i)+1);
  wc_2_rev(i,2)=wc_filt_2(i+11);
end

for i=1:1:number_nodes
  wc_2(i,1)=l(i);
  wc_2(i,2)=wc_2_rev((number_nodes-i)+1,2);
  wc(i,1)=l(i);
  wc(i,2)=(wc_1(i,2)+wc_2(i,2))/2;
end

% Done smoothing wc.  Next, smooth E_raw.  Backwards first:

x_f(1)=E_raw(1,2)-11*(E_raw(2,2)-E_raw(1,2));
x_f(2)=E_raw(1,2)-10*(E_raw(2,2)-E_raw(1,2));
x_f(3)=E_raw(1,2)-9*(E_raw(2,2)-E_raw(1,2));
x_f(4)=E_raw(1,2)-8*(E_raw(2,2)-E_raw(1,2));
x_f(5)=E_raw(1,2)-7*(E_raw(2,2)-E_raw(1,2));
x_f(6)=E_raw(1,2)-6*(E_raw(2,2)-E_raw(1,2));
x_f(7)=E_raw(1,2)-5*(E_raw(2,2)-E_raw(1,2));
x_f(8)=E_raw(1,2)-4*(E_raw(2,2)-E_raw(1,2));
x_f(9)=E_raw(1,2)-3*(E_raw(2,2)-E_raw(1,2));
x_f(10)=E_raw(1,2)-2*(E_raw(2,2)-E_raw(1,2));
x_f(11)=E_raw(1,2)-1*(E_raw(2,2)-E_raw(1,2));

for i=1:1:number_nodes
  x_f(i+11)=E_raw(i,2);
end

a_f=1;
b_f=[1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12];

E_filt_1=filter(b_f,a_f,x_f);

for i=1:1:number_nodes
  E_1(i,1)=l(i);
  E_1(i,2)=E_filt_1(i+11);
  % The two following lines create a reversed record so we 
  % can filter in the forward direction:
  E_raw_rev(i,1)=E_raw((number_nodes-i)+1,1);
  E_raw_rev(i,2)=E_raw((number_nodes-i)+1,2);
end

% Now forwards:

x_f(1)=E_raw_rev(1,2)-11*(E_raw_rev(2,2)-E_raw_rev(1,2));
x_f(2)=E_raw_rev(1,2)-10*(E_raw_rev(2,2)-E_raw_rev(1,2));
x_f(3)=E_raw_rev(1,2)-9*(E_raw_rev(2,2)-E_raw_rev(1,2));
x_f(4)=E_raw_rev(1,2)-8*(E_raw_rev(2,2)-E_raw_rev(1,2));
x_f(5)=E_raw_rev(1,2)-7*(E_raw_rev(2,2)-E_raw_rev(1,2));
x_f(6)=E_raw_rev(1,2)-6*(E_raw_rev(2,2)-E_raw_rev(1,2));
x_f(7)=E_raw_rev(1,2)-5*(E_raw_rev(2,2)-E_raw_rev(1,2));
x_f(8)=E_raw_rev(1,2)-4*(E_raw_rev(2,2)-E_raw_rev(1,2));
x_f(9)=E_raw_rev(1,2)-3*(E_raw_rev(2,2)-E_raw_rev(1,2));
x_f(10)=E_raw_rev(1,2)-2*(E_raw_rev(2,2)-E_raw_rev(1,2));
x_f(11)=E_raw_rev(1,2)-1*(E_raw_rev(2,2)-E_raw_rev(1,2));

for i=1:1:number_nodes
  x_f(i+11)=E_raw_rev(i,2);
end

a_f=1;
b_f=[1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12];

E_filt_2=filter(b_f,a_f,x_f);

for i=1:1:number_nodes
  E_2_rev(i,1)=l((number_nodes-i)+1);
  E_2_rev(i,2)=E_filt_2(i+11);
end

for i=1:1:number_nodes
  E_2(i,1)=l(i);
  E_2(i,2)=E_2_rev((number_nodes-i)+1,2);
  E(i,1)=l(i);
  E(i,2)=(E_1(i,2)+E_2(i,2))/2;
end

% Done smoothing E.  Smooth P_raw, backwards first:

x_f(1)=P_raw(1,2)-11*(P_raw(2,2)-P_raw(1,2));
x_f(2)=P_raw(1,2)-10*(P_raw(2,2)-P_raw(1,2));
x_f(3)=P_raw(1,2)-9*(P_raw(2,2)-P_raw(1,2));
x_f(4)=P_raw(1,2)-8*(P_raw(2,2)-P_raw(1,2));
x_f(5)=P_raw(1,2)-7*(P_raw(2,2)-P_raw(1,2));
x_f(6)=P_raw(1,2)-6*(P_raw(2,2)-P_raw(1,2));
x_f(7)=P_raw(1,2)-5*(P_raw(2,2)-P_raw(1,2));
x_f(8)=P_raw(1,2)-4*(P_raw(2,2)-P_raw(1,2));
x_f(9)=P_raw(1,2)-3*(P_raw(2,2)-P_raw(1,2));
x_f(10)=P_raw(1,2)-2*(P_raw(2,2)-P_raw(1,2));
x_f(11)=P_raw(1,2)-1*(P_raw(2,2)-P_raw(1,2));

for i=1:1:number_nodes
  x_f(i+11)=P_raw(i,2);
end

a_f=1;
b_f=[1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12];

P_filt_1=filter(b_f,a_f,x_f);

for i=1:1:number_nodes
  P_1(i,1)=l(i);
  P_1(i,2)=P_filt_1(i+11);
  % The two following lines create a reversed record so we 
  % can filter in the forward direction:
  P_raw_rev(i,1)=P_raw((number_nodes-i)+1,1);
  P_raw_rev(i,2)=P_raw((number_nodes-i)+1,2);
end

% Now forwards:

x_f(1)=P_raw_rev(1,2)-11*(P_raw_rev(2,2)-P_raw_rev(1,2));
x_f(2)=P_raw_rev(1,2)-10*(P_raw_rev(2,2)-P_raw_rev(1,2));
x_f(3)=P_raw_rev(1,2)-9*(P_raw_rev(2,2)-P_raw_rev(1,2));
x_f(4)=P_raw_rev(1,2)-8*(P_raw_rev(2,2)-P_raw_rev(1,2));
x_f(5)=P_raw_rev(1,2)-7*(P_raw_rev(2,2)-P_raw_rev(1,2));
x_f(6)=P_raw_rev(1,2)-6*(P_raw_rev(2,2)-P_raw_rev(1,2));
x_f(7)=P_raw_rev(1,2)-5*(P_raw_rev(2,2)-P_raw_rev(1,2));
x_f(8)=P_raw_rev(1,2)-4*(P_raw_rev(2,2)-P_raw_rev(1,2));
x_f(9)=P_raw_rev(1,2)-3*(P_raw_rev(2,2)-P_raw_rev(1,2));
x_f(10)=P_raw_rev(1,2)-2*(P_raw_rev(2,2)-P_raw_rev(1,2));
x_f(11)=P_raw_rev(1,2)-1*(P_raw_rev(2,2)-P_raw_rev(1,2));

for i=1:1:number_nodes
  x_f(i+11)=P_raw_rev(i,2);
end

a_f=1;
b_f=[1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12];

P_filt_2=filter(b_f,a_f,x_f);

for i=1:1:number_nodes
  P_2_rev(i,1)=l((number_nodes-i)+1);
  P_2_rev(i,2)=P_filt_2(i+11);
end

for i=1:1:number_nodes
  P_2(i,1)=l(i);
  P_2(i,2)=P_2_rev((number_nodes-i)+1,2);
  P(i,1)=l(i);
  P(i,2)=(P_1(i,2)+P_2(i,2))/2;
end

% Done smoothing P.  Smooth h_raw, backwards first:

x_f(1)=h_raw(1,2)-11*(h_raw(2,2)-h_raw(1,2));
x_f(2)=h_raw(1,2)-10*(h_raw(2,2)-h_raw(1,2));
x_f(3)=h_raw(1,2)-9*(h_raw(2,2)-h_raw(1,2));
x_f(4)=h_raw(1,2)-8*(h_raw(2,2)-h_raw(1,2));
x_f(5)=h_raw(1,2)-7*(h_raw(2,2)-h_raw(1,2));
x_f(6)=h_raw(1,2)-6*(h_raw(2,2)-h_raw(1,2));
x_f(7)=h_raw(1,2)-5*(h_raw(2,2)-h_raw(1,2));
x_f(8)=h_raw(1,2)-4*(h_raw(2,2)-h_raw(1,2));
x_f(9)=h_raw(1,2)-3*(h_raw(2,2)-h_raw(1,2));
x_f(10)=h_raw(1,2)-2*(h_raw(2,2)-h_raw(1,2));
x_f(11)=h_raw(1,2)-1*(h_raw(2,2)-h_raw(1,2));

for i=1:1:number_nodes
  x_f(i+11)=h_raw(i,2);
end

a_f=1;
b_f=[1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12];

h_filt_1=filter(b_f,a_f,x_f);

for i=1:1:number_nodes
  h_1(i,1)=l(i);
  h_1(i,2)=h_filt_1(i+11);
  % The two following lines create a reversed record so we 
  % can filter in the forward direction:
  h_raw_rev(i,1)=h_raw((number_nodes-i)+1,1);
  h_raw_rev(i,2)=h_raw((number_nodes-i)+1,2);
end

% Now forwards:

x_f(1)=h_raw_rev(1,2)-11*(h_raw_rev(2,2)-h_raw_rev(1,2));
x_f(2)=h_raw_rev(1,2)-10*(h_raw_rev(2,2)-h_raw_rev(1,2));
x_f(3)=h_raw_rev(1,2)-9*(h_raw_rev(2,2)-h_raw_rev(1,2));
x_f(4)=h_raw_rev(1,2)-8*(h_raw_rev(2,2)-h_raw_rev(1,2));
x_f(5)=h_raw_rev(1,2)-7*(h_raw_rev(2,2)-h_raw_rev(1,2));
x_f(6)=h_raw_rev(1,2)-6*(h_raw_rev(2,2)-h_raw_rev(1,2));
x_f(7)=h_raw_rev(1,2)-5*(h_raw_rev(2,2)-h_raw_rev(1,2));
x_f(8)=h_raw_rev(1,2)-4*(h_raw_rev(2,2)-h_raw_rev(1,2));
x_f(9)=h_raw_rev(1,2)-3*(h_raw_rev(2,2)-h_raw_rev(1,2));
x_f(10)=h_raw_rev(1,2)-2*(h_raw_rev(2,2)-h_raw_rev(1,2));
x_f(11)=h_raw_rev(1,2)-1*(h_raw_rev(2,2)-h_raw_rev(1,2));

for i=1:1:number_nodes
  x_f(i+11)=h_raw_rev(i,2);
end

a_f=1;
b_f=[1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12];

h_filt_2=filter(b_f,a_f,x_f);

for i=1:1:number_nodes
  h_2_rev(i,1)=l((number_nodes-i)+1);
  h_2_rev(i,2)=h_filt_2(i+11);
end

for i=1:1:number_nodes
  h_2(i,1)=l(i);
  h_2(i,2)=h_2_rev((number_nodes-i)+1,2);
  h(i,1)=l(i);
  h(i,2)=(h_1(i,2)+h_2(i,2))/2;
end

% Done smoothing h.  Next smooth run_raw, but only over the land surface.  
% Backwards first:

i1          = i_land;
number_rrun = number_nodes-i1+1;

for i=i1:1:number_nodes
  rrun_raw(i-i1+1,1)=run_raw(i,1);
  rrun_raw(i-i1+1,2)=run_raw(i,2);
end

x_f(1)=rrun_raw(1,2)-11*(rrun_raw(2,2)-rrun_raw(1,2));
x_f(2)=rrun_raw(1,2)-10*(rrun_raw(2,2)-rrun_raw(1,2));
x_f(3)=rrun_raw(1,2)-9*(rrun_raw(2,2)-rrun_raw(1,2));
x_f(4)=rrun_raw(1,2)-8*(rrun_raw(2,2)-rrun_raw(1,2));
x_f(5)=rrun_raw(1,2)-7*(rrun_raw(2,2)-rrun_raw(1,2));
x_f(6)=rrun_raw(1,2)-6*(rrun_raw(2,2)-rrun_raw(1,2));
x_f(7)=rrun_raw(1,2)-5*(rrun_raw(2,2)-rrun_raw(1,2));
x_f(8)=rrun_raw(1,2)-4*(rrun_raw(2,2)-rrun_raw(1,2));
x_f(9)=rrun_raw(1,2)-3*(rrun_raw(2,2)-rrun_raw(1,2));
x_f(10)=rrun_raw(1,2)-2*(rrun_raw(2,2)-rrun_raw(1,2));
x_f(11)=rrun_raw(1,2)-1*(rrun_raw(2,2)-rrun_raw(1,2));

for i=1:1:number_rrun
  x_f(i+11)=rrun_raw(i,2);
end

a_f=1;
b_f=[1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12];

rrun_filt_1=filter(b_f,a_f,x_f);

for i=1:1:number_rrun
  rrun_1(i,1)=l(i+i1-1);
  rrun_1(i,2)=rrun_filt_1(i+11);
  % The two following lines create a reversed record so we 
  % can filter in the forward direction:
  rrun_raw_rev(i,1)=rrun_raw((number_rrun-i)+1,1);
  rrun_raw_rev(i,2)=rrun_raw((number_rrun-i)+1,2);
end

% Now forwards:

x_f(1)=rrun_raw_rev(1,2)-11*(rrun_raw_rev(2,2)-rrun_raw_rev(1,2));
x_f(2)=rrun_raw_rev(1,2)-10*(rrun_raw_rev(2,2)-rrun_raw_rev(1,2));
x_f(3)=rrun_raw_rev(1,2)-9*(rrun_raw_rev(2,2)-rrun_raw_rev(1,2));
x_f(4)=rrun_raw_rev(1,2)-8*(rrun_raw_rev(2,2)-rrun_raw_rev(1,2));
x_f(5)=rrun_raw_rev(1,2)-7*(rrun_raw_rev(2,2)-rrun_raw_rev(1,2));
x_f(6)=rrun_raw_rev(1,2)-6*(rrun_raw_rev(2,2)-rrun_raw_rev(1,2));
x_f(7)=rrun_raw_rev(1,2)-5*(rrun_raw_rev(2,2)-rrun_raw_rev(1,2));
x_f(8)=rrun_raw_rev(1,2)-4*(rrun_raw_rev(2,2)-rrun_raw_rev(1,2));
x_f(9)=rrun_raw_rev(1,2)-3*(rrun_raw_rev(2,2)-rrun_raw_rev(1,2));
x_f(10)=rrun_raw_rev(1,2)-2*(rrun_raw_rev(2,2)-rrun_raw_rev(1,2));
x_f(11)=rrun_raw_rev(1,2)-1*(rrun_raw_rev(2,2)-rrun_raw_rev(1,2));

for i=1:1:number_rrun
  x_f(i+11)=rrun_raw_rev(i,2);
end

a_f=1;
b_f=[1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12];

rrun_filt_2=filter(b_f,a_f,x_f);

for i=1:1:number_rrun
  rrun_2_rev(i,1)=l((number_nodes-i)+1);
  rrun_2_rev(i,2)=rrun_filt_2(i+11);
end

for i=1:1:number_rrun
  rrun_2(i,1)=l(i+i1-1);
  rrun_2(i,2)=rrun_2_rev((number_rrun-i)+1,2);
end

for i=1:1:number_nodes
  run(i,1)=l(i);
  if i<i1
    run(i,2)=run_raw(i,2);
  else
    run(i,2)=(rrun_1(i-i1+1,2)+rrun_2(i-i1+1,2))/2;
  end
end

% Done smoothing run.  Now that all fields have been generated and 
% smoothed, write 'em out:

out(:,1)=l';
out(:,2)=ts(:,2);
out(:,3)=tc(:,2);
out(:,4)=wc(:,2);
out(:,5)=E(:,2);
out(:,6)=P(:,2);
out(:,7)=h(:,2);
out(:,8)=run(:,2);
out(:,9)=ocean(:,2);

save Andes_climate_path1_base.dat /ascii out;

%initial_del_values;

% Plot data fields:

m_s_to_m_a = 365.25*24*60*60;

figure
subplot(3,2,1)
plot(ts(:,1)/1000,ts(:,2)-273.15,'b-')
hold
plot(tc(:,1)/1000,tc(:,2)-273.15,'r-')
xlabel('L, km')
ylabel('T_s (b); T_c (r), C')
grid

subplot(3,2,2)
plot(wc(:,1)/1000,wc(:,2)*1000,'b-')
xlabel('L, km')
ylabel('wc, mm')
grid

subplot(3,2,3)
plot(P(:,1)/1000,P(:,2)*m_s_to_m_a,'b-')
xlabel('L, km')
ylabel('P, m/a')
grid

subplot(3,2,4)
plot(E(:,1)/1000,E(:,2)*m_s_to_m_a,'r-')
xlabel('L, km')
ylabel('E, m/a')
grid

subplot(3,2,5)
plot(h(:,1)/1000,h(:,2)*100,'r-')
xlabel('L, km')
ylabel('R_h, %')
grid

subplot(3,2,6)
plot(run(:,1)/1000,run(:,2)*1000,'b-')
xlabel('L, km')
ylabel('Runoff, m/a')
grid

