% Isotope Model

%     1-dimensional model of water vapor transport based on
%     Hendricks, M. B., . J. DePaolo, and R. C. Cohen.  2000.
%     "Space and time variation of 'del 18 O' and 'del D' in 
%     precipitation: Can paleotemperature be estimated from ice 
%     cores?"  Global Biogeochemical Cycles, 14(3), 851-861.
%
%     This version is in Cartesian coordinates and has been developed
%     to calculate the isotopic composition of precipitation in 
%     the Andes

% Read in parameter values

read_values_Andes_path1

% Calculate v, dv/dl.  Integration will be accomplished in a series of 
% short along-path hops.  As a first stab, we'll assume that there is 
% no along-path % gradient in water vapor transport velocity at 
% beginning of the path (or, in other words, dv/dl=0).  

i        = 1;
v_int(i) = (F(i,2)*(E(i,2)-P(i,2)))/d_wc(i,2);

for i=1:1:(number_nodes-1)
  l_start  = l(i);
  l_stop   = l(i+1);
  wc_int   = wc(i,2);
  d_wc_int = d_wc(i,2);
  P_int    = P(i,2);
  E_int    = E(i,2);
  F_int    = F(i,2);

  % Integrator inputs:

  tspan      = [l_start l_stop];
  IC1        = 1/wc_int;
  IC2        = F_int*(E_int-P_int);
  IC3        = d_wc_int;
  d_v_int(i) = IC1*(IC2-v_int(i)*IC3);
  y_v        = [v_int(i)];

  % Integration:

  [T_V,Y_V] = ode45('derivs_v',tspan,y_v,'',IC1,IC2,IC3);

  % Initialize values for next along-path hop:

  last=size(Y_V,1);
  v_int(i+1)   = Y_V(last,1);
  d_v_int(i+1) = IC1*(IC2-v_int(i+1)*IC3);
end

% End of integration for v(l), d_v(l).  Assign to 2-D arrays:

for i=1:1:number_nodes
  v(i,1)   = l(i);
  v(i,2)   = v_int(i);
  d_v(i,1) = l(i);
  d_v(i,2) = d_v_int(i);
end

% Plot v(l), dv(l)/dl:

figure

subplot(2,1,1)
plot(v(:,1)/1000,v(:,2),'r-');
title('January Amazonian Effective Transport Velocities')
xlabel('Along-path length, km')
ylabel('v')

subplot(2,1,2)
plot(d_v(:,1)/1000,d_v(:,2),'r-');
xlabel('Along-path length, km')
ylabel('dv/dl')

print -dpsc Andes_path1_vel_jan.ps

% Let the integration begin.  It'll be accomplished in a series of
% short along-path hops.  

% Calculate seed values of del_18_a, del_D_a:
% In the arrays del_18 and del_D, the fields are as follows:

% del_18(:,1): along-path location (m)
% del_18(:,2): del_18_a
% del_18(:,3): del_18_p
% del_18(:,4): del_18_e

% del_D(:,1): along-path location (m)
% del_D(:,2): del_D_a
% del_D(:,3): del_D_p
% del_D(:,4): del_D_e

% Set initial del 18, del D values:

i           = 1;

%del_18(i,1) = l(i);
%del_18(i,2) = del_18_e(ts(i,2),del_18_w(i,2),h(i,2));
%del_18(i,3) = del_18_p(tc(i,2),del_18(i,2));
%del_18(i,4) = evap_del_18(del_18(i,2),del_18_w(i,2),tc(i,2),ts(i,2), ...
%                h(i,2),P(i,2),E(i,2),F(i,2),ocean(i,2));

%del_D(i,1)  = l(i);
%del_D(i,2)  = del_D_e(ts(i,2),del_18_w(i,2),h(i,2));
%del_D(i,3)  = del_D_p(tc(i,2),del_D(i,2));
%del_D(i,4)  = evap_del_D(del_D(i,2),del_18_w(i,2),tc(i,2),ts(i,2), ...
%                h(i,2),P(i,2),E(i,2),F(i,2),ocean(i,2));

%init_del_18 = -0.001; % Nominal Value
init_del_18 = -0.001; 
%init_d      = +0.009; % Nominal Value
init_d      = +0.009; 

init_del_D  = init_d + 8*init_del_18;

del_18(i,1) = l(i);
del_18(i,2) = (1/alpha_18_eff(tc(i,2)))*(1+init_del_18)-1;
del_18(i,3) = del_18_p(tc(i,2),del_18(i,2));
del_18(i,4) = evap_del_18(del_18(i,2),del_18_w(i,2),tc(i,2),ts(i,2), ...
              h(i,2),P(i,2),E(i,2),F(i,2),ocean(i,2));

del_D(i,1)  = l(i);
del_D(i,2)  = (1/alpha_D_eff(tc(i,2)))*(1+init_del_D)-1;
del_D(i,3)  = del_D_p(tc(i,2),del_D(i,2));
del_D(i,4)  = evap_del_D(del_D(i,2),del_18_w(i,2),tc(i,2),ts(i,2), ...
              h(i,2),P(i,2),E(i,2),F(i,2),ocean(i,2));

% Let the integration begin.  It'll be accomplished in a series of 
% short along-path hops.

for i=1:1:(number_nodes-1)
  l_start      = l(i);
  l_stop       = l(i+1);
  v_int        = v(i,2);
  wc_int       = wc(i,2);
  P_int        = P(i,2);
  E_int        = E(i,2);
  F_int        = F(i,2);
  ts_int       = ts(i,2);
  tc_int       = tc(i,2);
  h_int        = h(i,2);
  ocean_int    = ocean(i,2);
  del_18_w_int = del_18_w(i,2);

  % Integrator inputs:

  tspan = [l_start l_stop];
  IC1   = 1/(wc_int*v_int);
  y     = [del_18(i,2);del_D(i,2)];

  % Integration:

  [T,Y] = ode45('iso_derivs',tspan,y,'',IC1,del_18_w_int, ...
          tc_int,ts_int,h_int,P_int,E_int,F_int,ocean_int);

  % Initialize values for next along-path hop:

  last          = size(Y,1);

  del_18(i+1,1) = l(i+1);
  del_18(i+1,2) = Y(last,1);
  del_18(i+1,3) = del_18_p(tc(i+1,2),del_18(i+1,2));
  del_18(i+1,4) = evap_del_18(del_18(i+1,2),del_18_w(i+1,2), ...
    tc(i+1,2),ts(i+1,2),h(i+1,2),P(i+1,2),E(i+1,2),F(i+1,2),ocean(i+1,2));

  del_D(i+1,1)  = l(i+1);
  del_D(i+1,2)  = Y(last,2);
  del_D(i+1,3)  = del_D_p(tc(i+1,2),del_D(i+1,2));
  del_D(i+1,4)  = evap_del_D(del_D(i+1,2),del_18_w(i+1,2), ...
    tc(i+1,2),ts(i+1,2),h(i+1,2),P(i+1,2),E(i+1,2),F(i+1,2),ocean(i+1,2));

end % of integration

% Calculate deuterium excess of precipitation:

for i=1:1:number_nodes
  d_excess(i,1) = l(i);
  d_excess(i,2) = d_excess_calc(del_18(i,2),del_D(i,2));
  d_excess(i,3) = d_excess_calc(del_18(i,3),del_D(i,3));
  d_excess(i,4) = d_excess_calc(del_18(i,4),del_D(i,4));
end

% Calculate runoff-weighted mean surface del18, delD values:

for i=1:1:number_nodes
  if ocean(i,2)  == 1
    i1           = i+1;
  end
end

i2               = number_nodes;


for i=1:1:number_nodes
  del_18_s1(i,1) = del_18(i,1);
  del_18_s1(i,2) = del_18(i,3);
  del_18_s2(i,1) = del_18(i,1);
  del_18_s2(i,2) = ...
    (1+del_18(i,3))*((P(i,2)-E(i,2))/P(i,2))^(alpha_18_e(ts(i,2),h(i,2))-1)-1;
  del_D_s1(i,1)  = del_D(i,1);
  del_D_s1(i,2)  = del_D(i,3);
  del_D_s2(i,1)  = del_D(i,1);
  del_D_s2(i,2)  = ...
    (1+del_D(i,3))*((P(i,2)-E(i,2))/P(i,2))^(alpha_D_e(ts(i,2),h(i,2))-1)-1;
end

d18_s_avg1      = (sum((P(i1:i2,2)-E(i1:i2,2)).*del_18_s1(i1:i2,2)) ...
                  /sum(P(i1:i2,2)-E(i1:i2,2)))*1000
d18_s_avg2      = (sum((P(i1:i2,2)-E(i1:i2,2)).*del_18_s2(i1:i2,2)) ...
                  /sum(P(i1:i2,2)-E(i1:i2,2)))*1000
dD_s_avg1       = (sum((P(i1:i2,2)-E(i1:i2,2)).*del_D_s1(i1:i2,2)) ...
                  /sum(P(i1:i2,2)-E(i1:i2,2)))*1000
dD_s_avg2       = (sum((P(i1:i2,2)-E(i1:i2,2)).*del_D_s2(i1:i2,2)) ...
                  /sum(P(i1:i2,2)-E(i1:i2,2)))*1000
excess_s_avg1   = dD_s_avg1-8*d18_s_avg1
excess_s_avg2   = dD_s_avg2-8*d18_s_avg2

% Print/write output files

save_path1_results
plot_path1_results

% End of iso_Andes.m

